@@ -5,21 +5,25 @@
 # Copyright (C) 2004 Rob Taylor
 # Copyright (C) 2005, 2006 Collabora Ltd. <http://www.collabora.co.uk/>
 #
-# Licensed under the Academic Free License version 2.1
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use, copy,
+# modify, merge, publish, distribute, sublicense, and/or sell copies
+# of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+# DEALINGS IN THE SOFTWARE.
 
 from __future__ import generators
 
@@ -38,11 +42,9 @@ from _dbus_bindings import BUS_DAEMON_NAME, BUS_DAEMON_PATH,\
                            validate_bus_name, validate_object_path,\
                            BUS_SESSION, BUS_SYSTEM, BUS_STARTER,\
                            DBUS_START_REPLY_SUCCESS, \
-                           DBUS_START_REPLY_ALREADY_RUNNING, \
-                           SignalMessage,\
-                           HANDLER_RESULT_NOT_YET_HANDLED,\
-                           HANDLER_RESULT_HANDLED
+                           DBUS_START_REPLY_ALREADY_RUNNING
 from dbus.bus import BusConnection
+from dbus.lowlevel import SignalMessage
 
 try:
     import thread
@@ -73,16 +75,13 @@ class Bus(BusConnection):
                 Connect to the appropriate bus
             `private` : bool
                 If true, never return an existing shared instance, but instead
-                return a private connection
+                return a private connection.
+                :Deprecated: since 0.82.3. Use dbus.bus.BusConnection for
+                    private connections.
             `mainloop` : dbus.mainloop.NativeMainLoop
                 The main loop to use. The default is to use the default
                 main loop if one has been set up, or raise an exception
                 if none has been.
-        :ToDo:
-            - There is currently no way to connect this class to a custom
-              address.
-            - Some of this functionality should be available on
-              peer-to-peer D-Bus connections too.
         :Changed: in dbus-python 0.80:
             converted from a wrapper around a Connection to a Connection
             subclass.
@@ -115,15 +114,15 @@ class Bus(BusConnection):
 
     def close(self):
         t = self._bus_type
-        if self.__class__._shared_instances[t] is self:
+        if self.__class__._shared_instances.get(t) is self:
             del self.__class__._shared_instances[t]
         super(Bus, self).close()
 
     def get_connection(self):
-        """(Deprecated - in new code, just use self)
-
-        Return self, for backwards compatibility with earlier dbus-python
+        """Return self, for backwards compatibility with earlier dbus-python
         versions where Bus was not a subclass of Connection.
+
+        :Deprecated: since 0.80.0
         """
         return self
     _connection = property(get_connection, None, None,
@@ -167,15 +166,17 @@ class Bus(BusConnection):
 
     def __repr__(self):
         if self._bus_type == BUS_SESSION:
-            name = 'SESSION'
+            name = 'session'
         elif self._bus_type == BUS_SYSTEM:
-            name = 'SYSTEM'
+            name = 'system'
         elif self._bus_type == BUS_STARTER:
-            name = 'STARTER'
+            name = 'starter'
         else:
-            raise AssertionError('Unable to represent unknown bus type.')
+            name = 'unknown bus type'
 
-        return '<dbus.Bus on %s at %#x>' % (name, id(self))
+        return '<%s.%s (%s) at %#x>' % (self.__class__.__module__,
+                                        self.__class__.__name__,
+                                        name, id(self))
     __str__ = __repr__
 
 
