@@ -1,20 +1,24 @@
 # Copyright (C) 2007 Collabora Ltd. <http://www.collabora.co.uk/>
 #
-# Licensed under the Academic Free License version 2.1
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use, copy,
+# modify, merge, publish, distribute, sublicense, and/or sell copies
+# of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published
-# by the Free Software Foundation; either version 2.1 of the License, or
-# (at your option) any later version.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+# DEALINGS IN THE SOFTWARE.
 
 __all__ = ('Connection', 'SignalMatch')
 __docformat__ = 'reStructuredText'
@@ -26,15 +30,15 @@ except ImportError:
     import dummy_thread as thread
 import weakref
 
-from _dbus_bindings import Connection as _Connection, ErrorMessage, \
-                           MethodCallMessage, MethodReturnMessage, \
+from _dbus_bindings import Connection as _Connection, \
                            LOCAL_PATH, LOCAL_IFACE, \
                            validate_interface_name, validate_member_name,\
                            validate_bus_name, validate_object_path,\
                            validate_error_name, \
-                           HANDLER_RESULT_NOT_YET_HANDLED, \
-                           UTF8String, SignalMessage
+                           UTF8String
 from dbus.exceptions import DBusException
+from dbus.lowlevel import ErrorMessage, MethodCallMessage, SignalMessage, \
+                          MethodReturnMessage, HANDLER_RESULT_NOT_YET_HANDLED
 from dbus.proxies import ProxyObject
 
 
@@ -228,6 +232,8 @@ class SignalMatch(object):
 class Connection(_Connection):
     """A connection to another application. In this base class there is
     assumed to be no bus daemon.
+
+    :Since: 0.81.0
     """
 
     ProxyObjectClass = ProxyObject
@@ -261,6 +267,7 @@ class Connection(_Connection):
             does not exist.
         :Raises DBusException: if the implementation has failed
             to activate the given bus name.
+        :Since: 0.81.0
         """
         return bus_name
 
@@ -514,6 +521,7 @@ class Connection(_Connection):
         are None, the implementation may request that no reply is sent.
 
         :Returns: The dbus.lowlevel.PendingCall.
+        :Since: 0.81.0
         """
         if object_path == LOCAL_PATH:
             raise DBusException('Methods may not be called on the reserved '
@@ -560,13 +568,14 @@ class Connection(_Connection):
                 error_handler(TypeError('Unexpected type for reply '
                                         'message: %r' % message))
         return self.send_message_with_reply(message, msg_reply_handler,
-                                        timeout/1000.0,
+                                        timeout,
                                         require_main_loop=require_main_loop)
 
     def call_blocking(self, bus_name, object_path, dbus_interface, method,
                       signature, args, timeout=-1.0, utf8_strings=False,
                       byte_arrays=False):
         """Call the given method, synchronously.
+        :Since: 0.81.0
         """
         if object_path == LOCAL_PATH:
             raise DBusException('Methods may not be called on the reserved '
