@@ -1,23 +1,27 @@
-# Copyright (C) 2003, 2004, 2005, 2006 Red Hat Inc. <http://www.redhat.com/>
+# Copyright (C) 2003-2006 Red Hat Inc. <http://www.redhat.com/>
 # Copyright (C) 2003 David Zeuthen
 # Copyright (C) 2004 Rob Taylor
-# Copyright (C) 2005, 2006 Collabora Ltd. <http://www.collabora.co.uk/>
+# Copyright (C) 2005-2006 Collabora Ltd. <http://www.collabora.co.uk/>
 #
-# Licensed under the Academic Free License version 2.1
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use, copy,
+# modify, merge, publish, distribute, sublicense, and/or sell copies
+# of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+# DEALINGS IN THE SOFTWARE.
 
 __all__ = ('BusName', 'Object', 'method', 'signal')
 __docformat__ = 'restructuredtext'
@@ -32,12 +36,13 @@ except ImportError:
     import dummy_thread as thread
 
 import _dbus_bindings
-from dbus import SessionBus
+from dbus import SessionBus, Signature, Struct, validate_bus_name, \
+                 validate_object_path, INTROSPECTABLE_IFACE, ObjectPath
+from dbus.decorators import method, signal
 from dbus.exceptions import DBusException, \
                             NameExistsException, \
                             UnknownMethodException
-from dbus.decorators import method
-from dbus.decorators import signal
+from dbus.lowlevel import ErrorMessage, MethodReturnMessage
 from dbus.proxies import LOCAL_PATH
 
 
@@ -82,8 +87,13 @@ class BusName(object):
             `name` : str
                 The well-known name to be advertised
             `bus` : dbus.Bus
-                A Bus on which this service will be advertised; if None
-                (default) the session bus will be used
+                A Bus on which this service will be advertised.
+
+                Omitting this parameter or setting it to None has been
+                deprecated since version 0.82.1. For backwards compatibility,
+                if this is done, the global shared connection to the session
+                bus will be used.
+
             `allow_replacement` : bool
                 If True, other processes trying to claim the same well-known
                 name will take precedence over this one.
@@ -95,11 +105,14 @@ class BusName(object):
                 services waiting for the requested name if another service
                 already holds it.
         """
-        _dbus_bindings.validate_bus_name(name, allow_well_known=True,
-                                         allow_unique=False)
+        validate_bus_name(name, allow_well_known=True, allow_unique=False)
 
-        # get default bus
-        if bus == None:
+        # if necessary, get default bus (deprecated)
+        if bus is None:
+            import warnings
+            warnings.warn('Omitting the "bus" parameter to '
+                          'dbus.service.BusName.__init__ is deprecated',
+                          DeprecationWarning, stacklevel=2)
             bus = SessionBus()
 
         # see if this name is already defined, return it if so
@@ -234,7 +247,7 @@ def _method_lookup(self, method_name, dbus_interface):
 
 
 def _method_reply_return(connection, message, method_name, signature, *retval):
-    reply = _dbus_bindings.MethodReturnMessage(message)
+    reply = MethodReturnMessage(message)
     try:
         reply.append(signature=signature, *retval)
     except Exception, e:
@@ -263,8 +276,17 @@ def _method_reply_error(connection, message, exception):
     else:
         name = 'org.freedesktop.DBus.Python.%s.%s' % (exception.__module__, exception.__class__.__name__)
 
-    contents = traceback.format_exc()
-    reply = _dbus_bindings.ErrorMessage(message, name, contents)
+    et, ev, etb = sys.exc_info()
+    if ev is exception:
+        # The exception was actually thrown, so we can get a traceback
+        contents = ''.join(traceback.format_exception(et, ev, etb))
+    else:
+        # We don't have any traceback for it, e.g.
+        #   async_err_cb(MyException('Failed to badger the mushroom'))
+        # see also https://bugs.freedesktop.org/show_bug.cgi?id=12403
+        contents = ''.join(traceback.format_exception_only(exception.__class__,
+            exception))
+    reply = ErrorMessage(message, name, contents)
 
     connection.send_message(reply)
 
@@ -303,15 +325,15 @@ class InterfaceType(type):
             # convert signature into a tuple so length refers to number of
             # types, not number of characters. the length is checked by
             # the decorator to make sure it matches the length of args.
-            in_sig = tuple(_dbus_bindings.Signature(func._dbus_in_signature))
+            in_sig = tuple(Signature(func._dbus_in_signature))
         else:
             # magic iterator which returns as many v's as we need
             in_sig = _VariantSignature()
 
         if func._dbus_out_signature:
-            out_sig = _dbus_bindings.Signature(func._dbus_out_signature)
+            out_sig = Signature(func._dbus_out_signature)
         else:
-            # its tempting to default to _dbus_bindings.Signature('v'), but
+            # its tempting to default to Signature('v'), but
             # for methods that return nothing, providing incorrect
             # introspection data is worse than providing none at all
             out_sig = []
@@ -331,7 +353,7 @@ class InterfaceType(type):
         if func._dbus_signature:
             # convert signature into a tuple so length refers to number of
             # types, not number of characters
-            sig = tuple(_dbus_bindings.Signature(func._dbus_signature))
+            sig = tuple(Signature(func._dbus_signature))
         else:
             # magic iterator which returns as many v's as we need
             sig = _VariantSignature()
@@ -422,7 +444,7 @@ class Object(Interface):
                 Object's lifetime (unless it's released manually).
         """
         if object_path is not None:
-            _dbus_bindings.validate_object_path(object_path)
+            validate_object_path(object_path)
 
         if isinstance(conn, BusName):
             # someone's using the old API; don't gratuitously break them
@@ -564,10 +586,6 @@ class Object(Interface):
         and object path. If no connection or path is specified,
         the object ceases to be accessible via any connection or path.
 
-        It's not currently possible to export an object on more than one
-        connection or with more than one object-path, but this will be
-        supported in future.
-
         :Parameters:
             `connection` : dbus.connection.Connection or None
                 Only remove the object from this Connection. If None,
@@ -629,7 +647,7 @@ class Object(Interface):
             keywords = {}
 
             if parent_method._dbus_out_signature is not None:
-                signature = _dbus_bindings.Signature(parent_method._dbus_out_signature)
+                signature = Signature(parent_method._dbus_out_signature)
             else:
                 signature = None
 
@@ -644,6 +662,29 @@ class Object(Interface):
                 keywords[parent_method._dbus_sender_keyword] = message.get_sender()
             if parent_method._dbus_path_keyword:
                 keywords[parent_method._dbus_path_keyword] = message.get_path()
+            if parent_method._dbus_rel_path_keyword:
+                path = message.get_path()
+                rel_path = path
+                for exp in self._locations:
+                    # pathological case: if we're exported in two places,
+                    # one of which is a subtree of the other, then pick the
+                    # subtree by preference (i.e. minimize the length of
+                    # rel_path)
+                    if exp[0] is connection:
+                        if path == exp[1]:
+                            rel_path = '/'
+                            break
+                        if exp[1] == '/':
+                            # we already have rel_path == path at the beginning
+                            continue
+                        if path.startswith(exp[1] + '/'):
+                            # yes we're in this exported subtree
+                            suffix = path[len(exp[1]):]
+                            if len(suffix) < len(rel_path):
+                                rel_path = suffix
+                rel_path = ObjectPath(rel_path)
+                keywords[parent_method._dbus_rel_path_keyword] = rel_path
+
             if parent_method._dbus_destination_keyword:
                 keywords[parent_method._dbus_destination_keyword] = message.get_destination()
             if parent_method._dbus_message_keyword:
@@ -687,7 +728,7 @@ class Object(Interface):
                 if retval is None:
                     retval = ()
                 elif (isinstance(retval, tuple)
-                      and not isinstance(retval, _dbus_bindings.Struct)):
+                      and not isinstance(retval, Struct)):
                 # If the return is a tuple that is not a Struct, we use it
                 # as-is on the assumption that there are multiple return
                 # values - this is the usual Python idiom. (fd.o #10174)
@@ -700,13 +741,14 @@ class Object(Interface):
             # send error reply
             _method_reply_error(connection, message, exception)
 
-    @method('org.freedesktop.DBus.Introspectable', in_signature='', out_signature='s')
-    def Introspect(self):
+    @method(INTROSPECTABLE_IFACE, in_signature='', out_signature='s',
+            path_keyword='object_path', connection_keyword='connection')
+    def Introspect(self, object_path, connection):
         """Return a string of XML encoding this object's supported interfaces,
         methods and signals.
         """
-        reflection_data = '<!DOCTYPE node PUBLIC "-//freedesktop//DTD D-BUS Object Introspection 1.0//EN" "http://www.freedesktop.org/standards/dbus/1.0/introspect.dtd">\n'
-        reflection_data += '<node name="%s">\n' % (self._object_path)
+        reflection_data = _dbus_bindings.DBUS_INTROSPECT_1_0_XML_DOCTYPE_DECL_NODE
+        reflection_data += '<node name="%s">\n' % object_path
 
         interfaces = self._dbus_class_table[self.__class__.__module__ + '.' + self.__class__.__name__]
         for (name, funcs) in interfaces.iteritems():
@@ -720,8 +762,7 @@ class Object(Interface):
 
             reflection_data += '  </interface>\n'
 
-        for name in self._connection.list_exported_child_objects(
-                self._object_path):
+        for name in connection.list_exported_child_objects(object_path):
             reflection_data += '  <node name="%s"/>\n' % name
 
         reflection_data += '</node>\n'
